@@ -73,6 +73,15 @@ func DetermineImage(ctx context.Context, appName string, imageOrPath string) (im
 		}
 		opts.BuildArgs = extraArgs
 
+		if cfg != nil && cfg.Experimental != nil {
+			opts.UseZstd = cfg.Experimental.UseZstd
+		}
+
+		// use-zstd passed through flags takes precedence over the one set in config
+		if flag.IsSpecified(ctx, "use-zstd") {
+			opts.UseZstd = flag.GetBool(ctx, "use-zstd")
+		}
+
 		img, err = resolver.BuildImage(ctx, io, opts)
 		if err != nil {
 			return nil, err
